# Project Title

Utils for xbos services using for Python 3.6

## Getting Started

Set XBOS_SERVICES_UTILS_CONFIG_PATH2 environment variable. The path should link to a directory which includes the folder "Buildings" and file "all_zones.yml". The yml file should resolve to a dictionary {zone_name: (list str) zones names}.

### Installing

pip install xbos-services-utils3

## Running the tests

Start the service and run the .test/test.py file for testing.  

### Break down into end to end tests

Explain what these tests test and why

```
Give an example
```


## Author

* **Daniel Lengyel** - *Initial work* - [daniellengyel](https://github.com/daniellengyel)


## License

No License



